#include <cstring>

#include <vector>
#include <algorithm>

using namespace std;

#include "testlib.h"

const int N = 100 * 1000;
const int S = 128 * 1024;
const int M = 200 * 1000;
const int MAX_D = 1000 * 1000 * 1000;
const int L = 4;

struct Tree {
    int tab[2 * S];

    Tree() {
        for (int i = 0; i < 2 * S; i++) tab[i] = 0;
    }

    void insert(int p, int v) {
        p += S;
        for (tab[p] = v, p /= 2; p; p /= 2) {
            tab[p] = max(tab[2 * p], tab[2 * p + 1]);
        }
    }

    int get(int l, int r) {
        l += S, r += S;
        int re = max(tab[l], tab[r]);
        while ((l / 2) != (r / 2)) {
            if (!(l % 2)) re = max(re, tab[l + 1]);
            if (r % 2) re = max(re, tab[r - 1]);
            l /= 2, r /= 2;
        }
        return re;
    }
} tree;

int n, s, m;
int instability[N];
vector<int> worse[M];
pair<int, int> range[M];
vector<pair<int, int> > lines;
char mes[2][L];

bool check_mes() {
    for (int i = 0; i < L; i++) {
        if (mes[0][i] != mes[1][i]) {
            quitf(_wa, "expected %s, got %s", mes[0], mes[1]);
        }
    }
    return mes[0][0] == 'Y';
}

void check() {
    for (int i = 0; i < s; i++) {
        if (instability[lines[i].first] != lines[i].second) {
            quitf(_wa, "initial values changed",
                  lines[i].first, lines[i].second, instability[lines[i].first]);
        }
    }
    for (int i = 0; i < n; i++) {
        tree.insert(i, instability[i]);
    }
    for (int i = 0; i < m; i++) {
        int maxi = 0, mini = MAX_D + 1;
        int last = range[i].first;
        for (size_t j = 0; j < worse[i].size(); j++) {
            int v = worse[i][j];
            mini = min(mini, instability[v]);
            if (last <= v - 1) {
                maxi = max(maxi, tree.get(last, v - 1));
            }
            last = v + 1;
        }
        if (last <= range[i].second) {
            maxi = max(maxi, tree.get(last, range[i].second));
        }
        if (mini <= maxi) {
            quitf(_wa, "condition %d unsatisfied",
                  i + 1);
        }
    }
}

int main(int argc, char **argv) {

    registerTestlibCmd(argc, argv);

    n = inf.readInt();
    s = inf.readInt();
    m = inf.readInt();

    lines.resize(s);

    for (int i = 0; i < s; i++) {
        lines[i].first = inf.readInt();
        lines[i].second = inf.readInt();
        lines[i].first--;
    }
    for (int i = 0; i < m; i++) {
        int l, r, k;
        l = inf.readInt();
        r = inf.readInt();
        k = inf.readInt();
        l--, r--;
        range[i].first = l;
        range[i].second = r;
        worse[i].resize(k);
        for (int j = 0; j < k; j++) {
            worse[i][j] = inf.readInt();
            worse[i][j]--;
        }
    }

    string sss = ans.readToken();
    strcpy(mes[0], sss.c_str());

    sss = ouf.readToken();
    strncpy(mes[1], sss.c_str(), L);
    if (check_mes()) {
        for (int i = 0; i < n; i++) {
            instability[i] = ouf.readInt(1, MAX_D);
        }
        check();
    }
    quitf(_ok, "OK");
}
